@@ -29,12 +29,13 @@ describe 'basic nova' do
 
       # Nova resources
       class { '::nova':
-        database_connection     => 'mysql+pymysql://nova:a_big_secret@127.0.0.1/nova?charset=utf8',
-        api_database_connection => 'mysql+pymysql://nova_api:a_big_secret@127.0.0.1/nova_api?charset=utf8',
-        default_transport_url   => 'rabbit://nova:an_even_bigger_secret@127.0.0.1:5672/',
-        image_service           => 'nova.image.glance.GlanceImageService',
-        glance_api_servers      => 'localhost:9292',
-        debug                   => true,
+        database_connection           => 'mysql+pymysql://nova:a_big_secret@127.0.0.1/nova?charset=utf8',
+        api_database_connection       => 'mysql+pymysql://nova_api:a_big_secret@127.0.0.1/nova_api?charset=utf8',
+        placement_database_connection => 'mysql+pymysql://nova_placement:a_big_secret@127.0.0.1/nova_placement?charset=utf8',
+        default_transport_url         => 'rabbit://nova:an_even_bigger_secret@127.0.0.1:5672/',
+        image_service                 => 'nova.image.glance.GlanceImageService',
+        glance_api_servers            => 'localhost:9292',
+        debug                         => true,
       }
       class { '::nova::db::mysql':
         password => 'a_big_secret',
@@ -42,19 +43,41 @@ describe 'basic nova' do
       class { '::nova::db::mysql_api':
         password => 'a_big_secret',
       }
+      class { '::nova::db::mysql_placement':
+        password => 'a_big_secret',
+      }
       class { '::nova::keystone::auth':
         password => 'a_big_secret',
       }
+      class { '::nova::keystone::auth_placement':
+        password => 'a_big_secret',
+      }
       class { '::nova::keystone::authtoken':
         password => 'a_big_secret',
       }
+      # TODO(aschultz): ubuntu's version of these commands are too old. Only
+      # run the cell_v2 on the redhat test until after Ocata-m3 is available
+      # from UCA
+      if $::osfamily == 'RedHat' {
+        include '::nova::cell_v2::simple_setup'
+      }
       class { '::nova::api':
         service_name   => 'httpd',
       }
       include ::apache
-      class { '::nova::wsgi::apache':
+      class { '::nova::wsgi::apache_api':
         ssl => false,
       }
+      # The Ubuntu package is now broken, it tries to run the app with systemd.
+      # Until it's fixed, let's test it on Red Hat only.
+      if $::osfamily == 'RedHat' {
+        class { '::nova::wsgi::apache_placement':
+          ssl => false,
+        }
+        class { '::nova::placement':
+          password => 'a_big_secret',
+        }
+      }
       class { '::nova::cert': }
       class { '::nova::client': }
       class { '::nova::conductor': }
@@ -106,12 +129,18 @@ describe 'basic nova' do
       it { is_expected.to be_listening }
     end
 
+    if os[:family].casecmp('RedHat') == 0
+      describe port(80) do
+        it { is_expected.to be_listening }
+      end
+    end
+
     describe port(6080) do
       it { is_expected.to be_listening }
     end
 
     describe cron do
-      it { is_expected.to have_entry('1 0 * * * nova-manage db archive_deleted_rows --max_rows 100 >>/var/log/nova/nova-rowsflush.log 2>&1').with_user('nova') }
+      it { is_expected.to have_entry('1 0 * * * nova-manage db archive_deleted_rows --max_rows 100  >>/var/log/nova/nova-rowsflush.log 2>&1').with_user('nova') }
     end
 
     describe 'nova aggregate' do
